/*###############################################################################
# Copyright (C) MOXA Inc. All rights reserved.
#
# This software is distributed under the terms of the
# MOXA License.  See the file COPYING-MOXA for details.
#
# Purpose : Push button device
# Return : 0 on success; Other wise, modification failed.
# Author : Lock Lin
# Date : 2014-03-17
# Version : 1.0
# Notes :
##############################################################################*/


#include <stdint.h>
#include <linux/input.h>
#include <string.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <signal.h>
#define DEBUG 
#ifdef DEBUG
#define DEBUG_PRINT(fmt, args...)    fprintf(stderr, fmt, ## args)
#else
#define DEBUG_PRINT(fmt, args...)    /* Don't do anything in release builds */
#endif

static void action_handler(int fd, struct input_event *ev)
{
	blink_led ("GREEN");
	DEBUG_PRINT("Detect Button is pressed. Blink GREEN\n");
	if (mx_btn_event_detect(fd, 5) == 1) {
		/* Release button under 5s, disable action */
		DEBUG_PRINT("release button within 5s. DO NOTHING\n");
		off_all_led();
		onoff_led ("GREEN", 1);
	} else { /* push button over 5s */
		DEBUG_PRINT("push button over 5s\n");
		off_all_led();
		onoff_led ("GREEN", 1);
		exec_cmd("setdef");
	}

}
int main (int argc, char **argv)
{
	int fd, ret, rd;
	struct input_event ev[64];

	fd = mx_open_device();
	if (fd < 0) {
		perror("push_btn");
		return 1;
	}

	//off_all_led();
	DEBUG_PRINT("Testing ... (interrupt to exit)\n");

	while (1) {
		rd = read(fd, ev, sizeof(struct input_event) * 64);
		if (rd < (int) sizeof(struct input_event)) {
			perror("\nprog_btn: error reading");
			return 1;
		}
		if (ev[0].value == 0)
			continue;
		else {
			action_handler(fd, ev);
		}
	}
	mx_close_device(fd);
}

